package cn.iocoder.yudao.module.system.service.downloadLog;

import cn.hutool.core.io.FileUtil;
import cn.iocoder.yudao.framework.apollo.core.event.export.*;
import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.i18n.core.I18nMessage;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.framework.mybatis.core.util.MyBatisUtils;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.framework.redis.helper.RedisHelper;
import cn.iocoder.yudao.framework.security.core.LoginUser;
import cn.iocoder.yudao.framework.security.core.util.SecurityFrameworkUtils;
import cn.iocoder.yudao.module.infra.api.file.FileApi;
import cn.iocoder.yudao.module.system.controller.admin.user.vo.user.UserMarkVO;
import cn.iocoder.yudao.module.system.convert.downloadLog.DownloadLogConvert;
import cn.iocoder.yudao.module.system.dal.dataobject.downloadLog.DownloadLogDO;
import cn.iocoder.yudao.module.system.dal.mysql.downloadLog.DownloadLogMapper;
import cn.iocoder.yudao.module.system.enums.download.DownloadTypeEnum;
import cn.iocoder.yudao.module.system.mq.message.file.FileMakeMessage;
import cn.iocoder.yudao.module.system.mq.producer.file.FileProducer;
import cn.iocoder.yudao.module.system.vo.downloadLog.DownloadLogCreateReqVO;
import cn.iocoder.yudao.module.system.vo.downloadLog.DownloadLogQueryVO;
import cn.iocoder.yudao.module.system.vo.downloadLog.DownloadLogUpdateReqVO;
import com.baomidou.mybatisplus.core.metadata.IPage;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.context.ApplicationContext;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;
import java.util.Collection;
import java.util.Date;
import java.util.List;
import java.util.Objects;
import java.util.concurrent.TimeUnit;

import static cn.iocoder.yudao.framework.common.exception.util.ServiceExceptionUtil.exception;
import static cn.iocoder.yudao.framework.redis.constant.Constant.FILE_DOWN_LOG_EXPIRED_KEY;
import static cn.iocoder.yudao.module.system.enums.ErrorCodeConstants.DOWNLOAD_LOG_NOT_EXISTS;

/**
 * 下载日志 Service 实现类
 *
 * @author 江楠
 */
@Service
@Validated
@Slf4j
public class DownloadLogServiceImpl extends AbstractService<DownloadLogMapper, DownloadLogDO> implements DownloadLogService {

    @Resource
    private DownloadLogMapper downloadLogMapper;
    @Resource
    private FileProducer fileProducer;
    @Resource
    private FileApi fileApi;
    @Resource
    private ApplicationContext applicationContext;
    @Resource
    private RedisHelper redisHelper;

    @Override
    public Long createDownloadLog(DownloadLogCreateReqVO createReqVO) {
        // 插入
        DownloadLogDO downloadLog = DownloadLogConvert.INSTANCE.convert(createReqVO);
        downloadLogMapper.insert(downloadLog);
        // 返回
        return downloadLog.getId();
    }

    @Override
    public void updateDownloadLog(DownloadLogUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateDownloadLogExists(updateReqVO.getId());
        // 更新
        DownloadLogDO updateObj = DownloadLogConvert.INSTANCE.convert(updateReqVO);
        downloadLogMapper.updateById(updateObj);
    }

    @Override
    public void deleteDownloadLog(Long id) {
        // 校验存在
        this.validateDownloadLogExists(id);
        // 删除
        downloadLogMapper.deleteById(id);
    }

    private void validateDownloadLogExists(Long id) {
        if (downloadLogMapper.selectById(id) == null) {
            throw exception(DOWNLOAD_LOG_NOT_EXISTS);
        }
    }

    @Override
    public DownloadLogDO getDownloadLog(Long id) {
        return downloadLogMapper.selectById(id);
    }

    @Override
    public List<DownloadLogDO> getDownloadLogList(Collection<Long> ids) {
        return downloadLogMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<DownloadLogDO> getDownloadLogPage(DownloadLogQueryVO query, PageVO page) {
        IPage<DownloadLogDO> mpPage = MyBatisUtils.buildPage(page);
        long total = downloadLogMapper.count(query);
        log.warn(I18nMessage.getLang().toString());
        int start = (page.getPage() - 1) * page.getRows();
        int size = page.getRows();
        List<DownloadLogDO> list = downloadLogMapper.list(start, size, query);
        return new PageResult<>(list, total, mpPage.getSize(), page.getPage(), (total + mpPage.getSize() - 1) / mpPage.getSize());
    }

    @Override
    public List<DownloadLogDO> getDownloadLogList(DownloadLogQueryVO query) {
        return downloadLogMapper.selectList(query);
    }

    @Override
    public void removeTemporaryFile(Long id) {
        DownloadLogDO downloadLogDO = downloadLogMapper.selectById(id);
        if (Objects.nonNull(downloadLogDO) && downloadLogDO.getTemporaryFile()) {
            // 删除临时文件
            if (Objects.nonNull(downloadLogDO.getFileId())) {
                try {
                    fileApi.deleteFile(downloadLogDO.getFileId());
                } catch (Exception e) {
                    log.error("删除{}文件失败，原因是：{}", downloadLogDO.getName(), e.getMessage());
                }
            } else {
                if (StringUtils.isNotBlank(downloadLogDO.getPath())) {
                    FileUtil.del(downloadLogDO.getPath());
                }
            }
            downloadLogDO.setStatus(4);
            downloadLogMapper.updateById(downloadLogDO);
        }
    }

    @Override
    public UserMarkVO markCount(Integer userType, Long userId) {
        return downloadLogMapper.markCount(userType, userId);
    }

    @Override
    public void retry(Long id) {
        DownloadLogDO downloadLogDO = downloadLogMapper.selectById(id);
        if (Objects.nonNull(downloadLogDO) && downloadLogDO.getTemporaryFile()) {
            // 删除临时文件
            if (Objects.nonNull(downloadLogDO.getFileId())) {
                try {
                    fileApi.deleteFile(downloadLogDO.getFileId());
                } catch (Exception e) {
                    log.error("删除{}文件失败，原因是：{}", downloadLogDO.getName(), e.getMessage());
                }
            } else {
                if (StringUtils.isNotBlank(downloadLogDO.getPath())) {
                    FileUtil.del(downloadLogDO.getPath());
                }
            }
            // TODO 此处是否有业务需要加入放入队列的判断待定
            // 导出记录放入队列后，记录状态改为处理中
            downloadLogDO.setStatus(1);
            downloadLogMapper.updateById(downloadLogDO);
            fileProducer.sendExcelExportMessage(downloadLogDO.getId(), downloadLogDO.getType(), downloadLogDO.getRequestParams());
        } else {
            throw exception(DOWNLOAD_LOG_NOT_EXISTS);
        }
    }

    @Override
    public void del(Long id) {
        DownloadLogDO downloadLogDO = downloadLogMapper.selectById(id);
        if (Objects.nonNull(downloadLogDO) && downloadLogDO.getTemporaryFile()) {
            // 删除临时文件
            if (Objects.nonNull(downloadLogDO.getFileId())) {
                try {
                    fileApi.deleteFile(downloadLogDO.getFileId());
                } catch (Exception e) {
                    log.error("删除{}文件失败，原因是：{}", downloadLogDO.getName(), e.getMessage());
                }
            } else {
                if (StringUtils.isNotBlank(downloadLogDO.getPath())) {
                    FileUtil.del(downloadLogDO.getPath());
                }
            }
            downloadLogMapper.deleteById(downloadLogDO.getId());
        } else {
            throw exception(DOWNLOAD_LOG_NOT_EXISTS);
        }
    }

    @Override
    public Long sendFileMake(Integer type, Boolean temporaryFile, String businessNo, Integer lang, String name, String fileSuffix, Integer userType, String requestParams) {
        // 插入
        DownloadLogDO downloadLog = new DownloadLogDO();
        downloadLog.setTemporaryFile(temporaryFile);
        downloadLog.setType(type);
        downloadLog.setStatus(0);
        downloadLog.setName(name);
        downloadLog.setLang(lang);
        downloadLog.setBusinessNo(businessNo);
        downloadLog.setFileSuffix(fileSuffix);
        downloadLog.setRequestParams(requestParams);
        downloadLog.setUserType(userType);
        downloadLog.setNum(0);
        LoginUser user = SecurityFrameworkUtils.getLoginUser();
        Date now = new Date();
        downloadLog.setUserId(user.getId());
        downloadLog.setCreator(String.valueOf(user.getId()));
        downloadLog.setCreateTime(now);
        downloadLog.setUpdater(String.valueOf(user.getId()));
        downloadLog.setUpdateTime(now);
        downloadLogMapper.insert(downloadLog);
        // TODO 此处是否有业务需要加入放入队列的判断待定
        // 导出记录放入队列后，记录状态改为处理中
        downloadLog.setStatus(1);
        downloadLogMapper.updateById(downloadLog);
        fileProducer.sendExcelExportMessage(downloadLog.getId(), type, requestParams);
        // 返回
        return downloadLog.getId();
    }

    @Override
    public void doFileMake(FileMakeMessage message) {
        DownloadLogDO downloadLog = downloadLogMapper.selectById(message.getLogId());
        if (Objects.isNull(downloadLog)) {
            throw exception(DOWNLOAD_LOG_NOT_EXISTS);
        }
        DownloadTypeEnum typeEnum = DownloadTypeEnum.type(message.getType());
        switch (typeEnum) {
            case ORDER_SEARCH_EXCEL_EXPORT:
                // 订单搜索导出
                orderExcelExportPushEvent(downloadLog);
                break;
            case CARGO_CONTROL_ORDER_SEARCH_EXCEL_EXPORT:
                // 控货订单搜索导出
                orderCargoControlExcelExportPushEvent(downloadLog);
                break;
            case EXCEPTION_ORDER_STATISTICS_SEARCH_EXCEL_EXPORT:
                // 异常订单统计导出
                exceptionOrderStatisticsExcelExportPushEvent(downloadLog);
                break;
            case RETURN_ORDER_SEARCH_EXCEL_EXPORT:
                // 退仓订单搜索导出
                returnOrderExcelExportPushEvent(downloadLog);
                break;
            case HEAVY_ORDER_SEARCH_EXCEL_EXPORT:
                // 重货订单搜索导出
                heavyOrderExcelExportPushEvent(downloadLog);
                break;
            case SALE_REPAY_ORDER_SEARCH_EXCEL_EXPORT:
                // 售后赔偿订单导出
                saleRepayExcelExportPushEvent(downloadLog);
                break;
            case CUSTOMS_ORDER_SEARCH_EXCEL_EXPORT:
                // 售后赔偿订单导出
                customsExcelExportPushEvent(downloadLog);
                break;
            case SHIPPING_ORDER_SEARCH_EXCEL_EXPORT:
                // 售后赔偿订单导出
                shippingExcelExportPushEvent(downloadLog);
                break;
            case ADVANCE_ORDER_SEARCH_EXCEL_EXPORT:
                // 售后赔偿订单导出
                advanceExcelExportPushEvent(downloadLog);
                break;
            case CONTAINER_NUMBER_ORDER_SEARCH_EXCEL_EXPORT:
                // 售后赔偿订单导出
                containerNumberExcelExportPushEvent(downloadLog);
                break;
            // ......不同类型的文件制作
            case SHIPMENT_PRELOAD_EXCEL_EXPORT:
                //预装单导出
                shipmentPreloadExcelExportPushEvent(downloadLog);
                break;
            //异常订单导出
            case EXCEPTION_ORDER_EXCEL_EXPORT:
                exceptionOrderExcelExportPushEvent(downloadLog);
                break;
            //已装单导出
            case SHIPMENT_LOAD_EXCEL_EXPORT:
//                shipmentLoadExcelExportPushEvent(downloadLog);
                //总体切换
                shipmentLoadExcelExportPushEvent2(downloadLog);
                break;
            //应收汇总导出修改导出Excel样式
            case SHIPMENT_RECEIVABLE_EXCEL_EXPORT:
                //老模板导出方式
                //shipmentReceivableExcelExportPushEvent(downloadLog);
                shipmentReceivableExcelExportPushEvent2(downloadLog);
                break;
            //提单打包导出
            case SHIPMENT_BILLING_ZIP_EXPORT:
                shipmentBillingZipExportPushEvent(downloadLog);
                break;
            //产品导出
            case PRODUCT_EXCEL_EXPORT:
                productExcelExportPushEvent(downloadLog);
                break;
            //产品价格导出
            case PRODUCT_PRICE_EXCEL_EXPORT:
                productPriceExcelExportPushEvent(downloadLog);
                break;
            //全部客户导出
            case CUSTOMER_EXCEL_EXPORT:
                customerExcelExportPushEvent(downloadLog);
                break;
            //我的客户导出
            case CUSTOMER_MINE_EXCEL_EXPORT:
                customerMineExcelExportPushEvent(downloadLog);
                break;
            //我的待接收客户导出
            case CUSTOMER_WAIT_CONFIRM_PUBLIC_EXCEL_EXPORT:
                customerWaitConfirmExcelExportPushEvent(downloadLog);
                break;
            //公海池客户导出
            case CUSTOMER_PUBLIC_EXCEL_EXPORT:
                customerPublicExcelExportPushEvent(downloadLog);
                break;
            //待分配客户导出
            case CUSTOMER_WAIT_DISTRIBUTION_PUBLIC_EXCEL_EXPORT:
                customerWaitDistributionExcelExportPushEvent(downloadLog);
                break;
            //空运应收汇总导出
            case AIR_BILL_RECEIVABLE_EXCEL_EXPORT:
                airBillReceivableExcelExportPushEvent(downloadLog);
                break;
            //潜在客户
            case CUSTOMER_POTENTIAL_EXCEL_EXPORT:
                customerPotentialExcelExportPushEvent(downloadLog);
                break;
            //间接客户
            case CUSTOMER_INDIRECT_EXCEL_EXPORT:
                customerIndirectExcelExportPushEvent(downloadLog);
                break;
            //部门客户列表导出
            case CUSTOMER_DEPT_EXCEL_EXPORT:
                customerDeptExcelExportPushEvent(downloadLog);
                break;
            case SHIPMENT_SUMMERY_EXCEL_EXPORT:
                shipmentSummeryExcelExportPushEvent(downloadLog);
                break;
            case SHIPMENT_SEA_PRELOAD_EXCEL_EXPORT:
                //海运预装单导出
                shipmentSeaPreloadExcelExportPushEvent(downloadLog);
                break;
            case SHIPMENT_AIR_LOAD_EXCEL_EXPORT:
                //空运预装单
                shipmentAirLoadExcelExportPushEvent(downloadLog);
                break;
            case ACHIEVEMENT_DETAIL_EXCEL_EXPORT:
                achievementDetailExcelExportPushEvent(downloadLog);
                break;
            case REPORT_CSSTOMER_ANALYSIS:
                //客户分析报表
                REPORT_CSSTOMER_ANALYSIS_Event(downloadLog);
                break;
            case REPORT_SALES_ANALYSIS:
                //销售分析报表
                REPORT_SALES_ANALYSIS_Event(downloadLog);
                break;
            default:
                downloadLog.setResult("unknown type");
                break;
        }
        if (StringUtils.isBlank(downloadLog.getDownloadUrl())) {
            // 失败
            downloadLog.setStatus(3);
            if (StringUtils.isBlank(downloadLog.getResult())) {
                downloadLog.setResult("fail");
            }
        } else {
            // 成功
            downloadLog.setStatus(2);
            downloadLog.setResult("success");
        }
        downloadLogMapper.updateById(downloadLog);

        if (downloadLog.getTemporaryFile()) {
            // 临时文件，需要定时12小时后删除
            // 此处将记录id和地址放入redis计时，监听redis的key过期后执行删除临时文件业务
            String key = FILE_DOWN_LOG_EXPIRED_KEY + downloadLog.getId();
            // 设置12小时过期key
            redisHelper.set(key, downloadLog.getId().toString(), 12, TimeUnit.HOURS);
        }
    }

    private void achievementDetailExcelExportPushEvent(DownloadLogDO downloadLog) {
        AchievementDetailExcelExportPushEvent event = new AchievementDetailExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void shipmentAirLoadExcelExportPushEvent(DownloadLogDO downloadLog) {
        ShipmentAirLoadExcelExportPushEvent event = new ShipmentAirLoadExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void shipmentSeaPreloadExcelExportPushEvent(DownloadLogDO downloadLog) {
        ShipmentSeaPreloadExcelExportPushEvent event = new ShipmentSeaPreloadExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void shipmentSummeryExcelExportPushEvent(DownloadLogDO downloadLog) {
        ShipmentSummeryExcelExportPushEvent event = new ShipmentSummeryExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void airBillReceivableExcelExportPushEvent(DownloadLogDO downloadLog) {
        AirBillReceivableExcelExportPushEvent event = new AirBillReceivableExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void productPriceExcelExportPushEvent(DownloadLogDO downloadLog) {
        ProductPriceExcelExportPushEvent event = new ProductPriceExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void customerExcelExportPushEvent(DownloadLogDO downloadLog) {
        CustomerExcelExportPushEvent event = new CustomerExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void customerMineExcelExportPushEvent(DownloadLogDO downloadLog) {
        CustomerMineExcelExportPushEvent event = new CustomerMineExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }


    private void customerWaitConfirmExcelExportPushEvent(DownloadLogDO downloadLog) {
        CustomerWaitConfirmExcelExportPushEvent event = new CustomerWaitConfirmExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }


    private void customerPublicExcelExportPushEvent(DownloadLogDO downloadLog) {
        CustomerPublicExcelExportPushEvent event = new CustomerPublicExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }


    private void customerWaitDistributionExcelExportPushEvent(DownloadLogDO downloadLog) {
        CustomerWaitDistributionExcelExportPushEvent event = new CustomerWaitDistributionExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }


    private void customerPotentialExcelExportPushEvent(DownloadLogDO downloadLog) {
        CustomerPotentialExcelExportPushEvent event = new CustomerPotentialExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }


    private void customerIndirectExcelExportPushEvent(DownloadLogDO downloadLog) {
        IndirectCustomerExcelExportPushEvent event = new IndirectCustomerExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }


    private void customerDeptExcelExportPushEvent(DownloadLogDO downloadLog) {
        CustomerDeptExcelExportPushEvent event = new CustomerDeptExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void productExcelExportPushEvent(DownloadLogDO downloadLog) {
        ProductExcelExportPushEvent event = new ProductExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void shipmentBillingZipExportPushEvent(DownloadLogDO downloadLog) {
        ShipmentBillingZipExportPushEvent event = new ShipmentBillingZipExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void shipmentReceivableExcelExportPushEvent(DownloadLogDO downloadLog) {
        ShipmentReceivableExcelExportPushEvent event = new ShipmentReceivableExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    /*

     */
    private void shipmentReceivableExcelExportPushEvent2(DownloadLogDO downloadLog) {
        ShipmentReceivableExcelExportPushEvent2 event =
                new ShipmentReceivableExcelExportPushEvent2();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }


    private void shipmentLoadExcelExportPushEvent(DownloadLogDO downloadLog) {
        ShipmentLoadExcelExportPushEvent event = new ShipmentLoadExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    /*
     海运已装单导出
     */
    private void shipmentLoadExcelExportPushEvent2(DownloadLogDO downloadLog) {
        ShipmentLoadExcelExportPushEvent2 event =
                new ShipmentLoadExcelExportPushEvent2();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void shipmentPreloadExcelExportPushEvent(DownloadLogDO downloadLog) {
        ShipmentPreloadExcelExportPushEvent event = new ShipmentPreloadExcelExportPushEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void containerNumberExcelExportPushEvent(DownloadLogDO downloadLog) {
        ContainerNumberOrderExcelExportEvent event = new ContainerNumberOrderExcelExportEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void advanceExcelExportPushEvent(DownloadLogDO downloadLog) {
        AdvanceOrderExcelExportEvent event = new AdvanceOrderExcelExportEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void shippingExcelExportPushEvent(DownloadLogDO downloadLog) {
        ShippingOrderExcelExportEvent event = new ShippingOrderExcelExportEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void customsExcelExportPushEvent(DownloadLogDO downloadLog) {
        CustomsOrderExcelExportEvent event = new CustomsOrderExcelExportEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void saleRepayExcelExportPushEvent(DownloadLogDO downloadLog) {
        SaleRepayOrderExcelExportEvent event = new SaleRepayOrderExcelExportEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }


    private void orderExcelExportPushEvent(DownloadLogDO downloadLog) {
        OrderExcelExportEvent event = new OrderExcelExportEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void orderCargoControlExcelExportPushEvent(DownloadLogDO downloadLog) {
        OrderCargoControlExcelExportEvent event = new OrderCargoControlExcelExportEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void exceptionOrderStatisticsExcelExportPushEvent(DownloadLogDO downloadLog) {
        ExceptionOrderStatisticsExcelExportEvent event = new ExceptionOrderStatisticsExcelExportEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }


    private void returnOrderExcelExportPushEvent(DownloadLogDO downloadLog) {
        ReturnOrderExcelExportEvent event = new ReturnOrderExcelExportEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void heavyOrderExcelExportPushEvent(DownloadLogDO downloadLog) {
        HeavyOrderExcelExportEvent event = new HeavyOrderExcelExportEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    private void exceptionOrderExcelExportPushEvent(DownloadLogDO downloadLog) {
        ExceptionOrderExcelExportEvent event = new ExceptionOrderExcelExportEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

    /*

     客户分析
     */
    private void REPORT_CSSTOMER_ANALYSIS_Event(DownloadLogDO downloadLog) {
        ReportCustomerAnalysisExcelExportEvent event =
                new ReportCustomerAnalysisExcelExportEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());

    }

    /*
     销售分析报表
     */
    private void REPORT_SALES_ANALYSIS_Event(DownloadLogDO downloadLog) {
        ReportSalesAnalysisExcelExportEvent event =
                new ReportSalesAnalysisExcelExportEvent();
        event.setUserId(downloadLog.getUserId());
        event.setUserType(downloadLog.getUserType());
        event.setLang(downloadLog.getLang());
        event.setRequestParams(downloadLog.getRequestParams());
        applicationContext.publishEvent(event);
        downloadLog.setFileName(event.getFileName());
        downloadLog.setPath(event.getPath());
        downloadLog.setDownloadUrl(event.getUrl());
        downloadLog.setResult(event.getResult());
        downloadLog.setFileId(event.getFileId());
    }

}
